@@ -19,6 +19,12 @@ struct s_fans {
     char* path;  // TODO: unused
     char* fan_output_path;
     char* fan_manual_path;
+    int step_up;
+    int step_down;
+    int fan_id;
+    int old_speed;
+    int fan_max_speed;
+    int fan_min_speed;
     struct s_fans *next;
 };
 
@@ -28,4 +34,4 @@ typedef struct s_fans t_fans;
 extern t_sensors* sensors;
 extern t_fans* fans;
 
-#endif
\ No newline at end of file
+#endif
